==> jc-1.4.0.tar.gz: soot/jimple/parser/node/NodeCast.h <==
// public class soot.jimple.parser.node.NodeCast

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 9417b7695d1ce1d7 soot_jimple_parser_node_NodeCast

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_soot_jimple_parser_node_NodeCast_H_
#define _JC_soot_jimple_parser_node_NodeCast_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_soot_jimple_parser_node_NodeCast$object;

// Typedefs
typedef struct _jc_soot_jimple_parser_node_NodeCast$sub_refs	_jc_soot_jimple_parser_node_NodeCast$sub_refs;
typedef struct _jc_soot_jimple_parser_node_NodeCast$sub_nonrefs	_jc_soot_jimple_parser_node_NodeCast$sub_nonrefs;
typedef struct _jc_soot_jimple_parser_node_NodeCast$refs	_jc_soot_jimple_parser_node_NodeCast$refs;
typedef struct _jc_soot_jimple_parser_node_NodeCast$nonrefs	_jc_soot_jimple_parser_node_NodeCast$nonrefs;
typedef struct _jc_soot_jimple_parser_node_NodeCast$object	_jc_soot_jimple_parser_node_NodeCast$object;

typedef struct _jc_soot_jimple_parser_node_NodeCast$fields_struct	_jc_soot_jimple_parser_node_NodeCast$fields_struct;
typedef const struct _jc_soot_jimple_parser_node_NodeCast$vmethods	_jc_soot_jimple_parser_node_NodeCast$vmethods;
typedef const struct _jc_soot_jimple_parser_node_NodeCast$vtable	_jc_soot_jimple_parser_node_NodeCast$vtable;
typedef const struct _jc_soot_jimple_parser_node_NodeCast$vtype	_jc_soot_jimple_parser_node_NodeCast$vtype;

// Class fields structure
struct _jc_soot_jimple_parser_node_NodeCast$fields_struct {
	struct _jc_soot_jimple_parser_node_NodeCast$object	*instance;
};
extern _jc_soot_jimple_parser_node_NodeCast$fields_struct _jc_soot_jimple_parser_node_NodeCast$class_fields;

// Constructors
extern void _jc_soot_jimple_parser_node_NodeCast$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_jimple_parser_node_NodeCast$object *);

// Virtual methods
extern struct _jc_java_lang_Object$object *_jc_soot_jimple_parser_node_NodeCast$method$cast$7f4f4803dccc49ec(_jc_env *, struct _jc_soot_jimple_parser_node_NodeCast$object *, struct _jc_java_lang_Object$object *);

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_parser_node_NodeCast$method_info$cast$7f4f4803dccc49ec;

// Static methods
extern void _jc_soot_jimple_parser_node_NodeCast$method$_clinit$a816641e0ba8bfef(_jc_env *);

// Virtual methods structure
struct _jc_soot_jimple_parser_node_NodeCast$vmethods {
	struct _jc_java_lang_Object$object	*(*cast$7f4f4803dccc49ec)(_jc_env *, struct _jc_soot_jimple_parser_node_NodeCast$object *, struct _jc_java_lang_Object$object *);
};

// Vtable
struct _jc_soot_jimple_parser_node_NodeCast$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_parser_node_NodeCast$vmethods	soot_jimple_parser_node_NodeCast;
};

// Vtype
struct _jc_soot_jimple_parser_node_NodeCast$vtype {
	_jc_type			type;
	_jc_soot_jimple_parser_node_NodeCast$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_parser_node_NodeCast$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_jimple_parser_node_NodeCast$refs {
    _jc_soot_jimple_parser_node_NodeCast$sub_refs	soot_jimple_parser_node_NodeCast;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_parser_node_NodeCast$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_parser_node_NodeCast$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_parser_node_NodeCast$sub_nonrefs	soot_jimple_parser_node_NodeCast;
};

// Object instance structure
struct _jc_soot_jimple_parser_node_NodeCast$object {
	_jc_soot_jimple_parser_node_NodeCast$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_parser_node_NodeCast$vtype	*vtype;
	_jc_soot_jimple_parser_node_NodeCast$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_parser_node_NodeCast$vtype _jc_soot_jimple_parser_node_NodeCast$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_parser_node_NodeCast, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_parser_node_NodeCast$class_object;

#endif	/* _JC_soot_jimple_parser_node_NodeCast_H_ */

==> jc-1.4.6.tar.gz: soot/jimple/parser/node/NodeCast.h <==
// public class soot.jimple.parser.node.NodeCast

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 9417b7695d1ce1d7 soot_jimple_parser_node_NodeCast

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_soot_jimple_parser_node_NodeCast_H_
#define _JC_soot_jimple_parser_node_NodeCast_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_soot_jimple_parser_node_NodeCast$object;

// Typedefs
typedef struct _jc_soot_jimple_parser_node_NodeCast$sub_refs	_jc_soot_jimple_parser_node_NodeCast$sub_refs;
typedef struct _jc_soot_jimple_parser_node_NodeCast$sub_nonrefs	_jc_soot_jimple_parser_node_NodeCast$sub_nonrefs;
typedef struct _jc_soot_jimple_parser_node_NodeCast$refs	_jc_soot_jimple_parser_node_NodeCast$refs;
typedef struct _jc_soot_jimple_parser_node_NodeCast$nonrefs	_jc_soot_jimple_parser_node_NodeCast$nonrefs;
typedef struct _jc_soot_jimple_parser_node_NodeCast$object	_jc_soot_jimple_parser_node_NodeCast$object;

typedef struct _jc_soot_jimple_parser_node_NodeCast$fields_struct	_jc_soot_jimple_parser_node_NodeCast$fields_struct;
typedef const struct _jc_soot_jimple_parser_node_NodeCast$vmethods	_jc_soot_jimple_parser_node_NodeCast$vmethods;
typedef const struct _jc_soot_jimple_parser_node_NodeCast$vtable	_jc_soot_jimple_parser_node_NodeCast$vtable;
typedef const struct _jc_soot_jimple_parser_node_NodeCast$vtype	_jc_soot_jimple_parser_node_NodeCast$vtype;

// Class fields structure
struct _jc_soot_jimple_parser_node_NodeCast$fields_struct {
	struct _jc_soot_jimple_parser_node_NodeCast$object	*instance;
};
extern _jc_soot_jimple_parser_node_NodeCast$fields_struct _jc_soot_jimple_parser_node_NodeCast$class_fields;

// Constructors
extern void _jc_soot_jimple_parser_node_NodeCast$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_jimple_parser_node_NodeCast$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_java_lang_Object$object *_jc_soot_jimple_parser_node_NodeCast$method$cast$7f4f4803dccc49ec(_jc_env *, struct _jc_soot_jimple_parser_node_NodeCast$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_parser_node_NodeCast$method_info$cast$7f4f4803dccc49ec;

// Static methods
extern void _jc_soot_jimple_parser_node_NodeCast$method$_clinit$a816641e0ba8bfef(_jc_env *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_soot_jimple_parser_node_NodeCast$vmethods {
	struct _jc_java_lang_Object$object	*(*cast$7f4f4803dccc49ec)(_jc_env *, struct _jc_soot_jimple_parser_node_NodeCast$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_jimple_parser_node_NodeCast$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_parser_node_NodeCast$vmethods	soot_jimple_parser_node_NodeCast;
};

// Vtype
struct _jc_soot_jimple_parser_node_NodeCast$vtype {
	_jc_type			type;
	_jc_soot_jimple_parser_node_NodeCast$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_parser_node_NodeCast$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_jimple_parser_node_NodeCast$refs {
    _jc_soot_jimple_parser_node_NodeCast$sub_refs	soot_jimple_parser_node_NodeCast;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_parser_node_NodeCast$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_parser_node_NodeCast$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_parser_node_NodeCast$sub_nonrefs	soot_jimple_parser_node_NodeCast;
};

// Object instance structure
struct _jc_soot_jimple_parser_node_NodeCast$object {
	_jc_soot_jimple_parser_node_NodeCast$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_parser_node_NodeCast$vtype	*vtype;
	_jc_soot_jimple_parser_node_NodeCast$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_parser_node_NodeCast$vtype _jc_soot_jimple_parser_node_NodeCast$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_parser_node_NodeCast, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_parser_node_NodeCast$class_object;

#endif	/* _JC_soot_jimple_parser_node_NodeCast_H_ */
